@@ -227,7 +227,7 @@ SMALL = 2.0**(-30)
 SMALLEST_COUNTEREXAMPLE_FASTPRIME = 2047
 T = (type(mpz(1)), type(1), type(1L))
 DUMMY = 'dummy' # Dummy value throughout the program
-VERSION = '2.0'
+VERSION = '2.0.1'
 _12_LOG_2_OVER_49 = 12 * math.log(2) / 49
 RECORD = 1162795072109807846655696105569042240239
 
@@ -1375,7 +1375,6 @@ def command_line(veb, ra, ov, pr):
 		if n < 0:
 			print	-1
 			n = -n
-			continue
 		if n == 0:
 			print	'0 does not have a well-defined factorization.'
 			continue
